@@ -1,6 +1,8 @@
 from __future__ import annotations
 
 import argparse
+import csv
+import hashlib
 import json
 import os
 import signal
@@ -8,10 +10,13 @@ import subprocess
 import sys
 import time
 import webbrowser
+import zipfile
+from shutil import copy2
+from datetime import datetime
 from http.client import HTTPConnection
-from urllib.parse import quote_plus
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Iterable, Optional
+from urllib.parse import quote_plus
 
 from . import (
     ProjectPaths,
@@ -22,6 +27,14 @@ from . import (
     register_project,
     discover_project_root,
 )
+from .campaign import CampaignWorkspace, PlacementRef
+from .campaign.schemas import ExportCsv, ExportFile, ExportManifest, ExportRoute, ReviewState
+from .campaign.runner import (
+    DeterministicProviderError,
+    execute_generation,
+    plan_generation,
+    plan_from_batch_spec,
+)
 from .config import CONFIG_DIR_NAME, CONFIG_FILENAME, ProjectConfig
 from .gallery import serve_gallery
 from .generator import GenerationResult, build_generator
@@ -192,6 +205,87 @@ def build_parser() -> argparse.ArgumentParser:
     models_parser.add_argument("--provider", help="Filter results to a provider id")
     models_parser.set_defaults(func=cmd_models)
 
+    campaign_parser = subparsers.add_parser("campaign", help="Campaign workflow commands")
+    campaign_sub = campaign_parser.add_subparsers(dest="campaign_command", required=True)
+
+    campaign_init_parser = campaign_sub.add_parser("init", help="Scaffold a new campaign workspace")
+    campaign_init_parser.add_argument("campaign_id", help="Campaign identifier (lowercase slug)")
+    campaign_init_parser.add_argument("--name", help="Campaign display name")
+    campaign_init_parser.add_argument("--objective", help="Objective to seed the brief with")
+    campaign_init_parser.add_argument(
+        "--brief-file",
+        help="Optional YAML/JSON file containing initial brief data",
+    )
+    campaign_init_parser.add_argument(
+        "--placements",
+        help="Comma-separated placement template ids to include",
+    )
+    campaign_init_parser.add_argument(
+        "--metadata",
+        nargs="*",
+        default=(),
+        help="Additional asset metadata entries (key=value)",
+    )
+    campaign_init_parser.add_argument(
+        "--tags",
+        help="Comma-separated tag slugs",
+    )
+    campaign_init_parser.add_argument("--json", action="store_true")
+    campaign_init_parser.set_defaults(func=cmd_campaign_init)
+
+    campaign_generate_parser = campaign_sub.add_parser("generate", help="Generate variants for campaign placements")
+    campaign_generate_parser.add_argument("campaign_id", help="Campaign identifier")
+    campaign_generate_parser.add_argument(
+        "--routes",
+        help="Comma-separated route ids to generate (default: all)"
+    )
+    campaign_generate_parser.add_argument(
+        "--placements",
+        help="Comma-separated placement ids or template ids (default: all)",
+    )
+    campaign_generate_parser.add_argument("--variants", type=int, help="Override variant count per placement")
+    campaign_generate_parser.add_argument("--provider", help="Override provider id")
+    campaign_generate_parser.add_argument("--generator", help="Generator backend override (mock/openrouter)")
+    campaign_generate_parser.add_argument("--json", action="store_true")
+    campaign_generate_parser.set_defaults(func=cmd_campaign_generate)
+
+    campaign_batch_parser = campaign_sub.add_parser("batch", help="Execute batch spec for deterministic runs")
+    campaign_batch_parser.add_argument("campaign_id", help="Campaign identifier")
+    campaign_batch_parser.add_argument("--spec", help="Path to batch spec (default: campaign batch.yaml)")
+    campaign_batch_parser.add_argument("--generator", help="Generator backend override")
+    campaign_batch_parser.add_argument("--json", action="store_true")
+    campaign_batch_parser.set_defaults(func=cmd_campaign_batch)
+
+    campaign_review_parser = campaign_sub.add_parser("review", help="Update review state for a variant")
+    campaign_review_parser.add_argument("campaign_id", help="Campaign identifier")
+    campaign_review_parser.add_argument("--route", required=True, help="Route id")
+    campaign_review_parser.add_argument("--placement", required=True, help="Placement id")
+    campaign_review_parser.add_argument("--variant", type=int, required=True, help="Variant index (0-based)")
+    campaign_review_parser.add_argument(
+        "--state",
+        choices=["pending", "approved", "revise"],
+        required=True,
+        help="Review state to apply",
+    )
+    campaign_review_parser.add_argument("--notes", help="Optional review notes")
+    campaign_review_parser.add_argument("--json", action="store_true")
+    campaign_review_parser.set_defaults(func=cmd_campaign_review)
+
+    campaign_export_parser = campaign_sub.add_parser("export", help="Export campaign bundle for a platform")
+    campaign_export_parser.add_argument("campaign_id", help="Campaign identifier")
+    campaign_export_parser.add_argument("--platform", required=True, help="Platform id (e.g., meta_ads)")
+    campaign_export_parser.add_argument(
+        "--include",
+        default="approved",
+        help="Comma-separated review states to include (default: approved)",
+    )
+    campaign_export_parser.add_argument(
+        "--output",
+        help="Optional zip file path; defaults to the generated export directory",
+    )
+    campaign_export_parser.add_argument("--json", action="store_true")
+    campaign_export_parser.set_defaults(func=cmd_campaign_export)
+
     return parser
 
 
@@ -750,6 +844,378 @@ def cmd_models(args: argparse.Namespace) -> int:
     return 0
 
 
+def cmd_campaign_init(args: argparse.Namespace) -> int:
+    try:
+        config, paths = _prepare_project(args)
+    except (InvalidPathError, RuntimeError, ValueError) as exc:
+        return _fail(str(exc))
+
+    campaign_id = args.campaign_id.strip()
+    workspace = CampaignWorkspace(paths, campaign_id)
+
+    brief_data: Dict[str, Any] = {}
+    if args.brief_file:
+        try:
+            brief_data = _load_structured_data(args.brief_file)
+        except Exception as exc:  # noqa: BLE001
+            return _fail(f"Failed to load brief file: {exc}")
+    objective = args.objective or brief_data.get("objective")
+    if not objective:
+        objective = "TODO: update campaign objective"
+    brief_data.setdefault("objective", objective)
+
+    name = args.name or campaign_id.replace("_", " ").title()
+    tags = [tag.strip() for tag in (args.tags or "").split(",") if tag.strip()]
+    try:
+        assets = _parse_metadata(args.metadata or [])
+    except ValueError as exc:
+        return _fail(str(exc))
+
+    placement_refs: list[PlacementRef] = []
+    if args.placements:
+        placements = [item.strip() for item in args.placements.split(",") if item.strip()]
+        placement_refs = [PlacementRef(template_id=slug) for slug in placements]
+
+    existing = workspace.config_path.exists()
+    try:
+        config_obj = workspace.ensure_default_config(name=name, brief=brief_data)
+    except ValueError as exc:
+        return _fail(f"Invalid campaign brief: {exc}")
+
+    updated_brief = config_obj.brief.model_copy(update=brief_data)
+    config_obj = config_obj.model_copy(update={
+        "name": name,
+        "tags": tags,
+        "brief": updated_brief,
+        "placements": placement_refs or config_obj.placements,
+        "assets": assets or config_obj.assets,
+    })
+    workspace.save_config(config_obj)
+
+    result = {
+        "project_root": str(config.project_root),
+        "campaign_id": campaign_id,
+        "config_path": str(workspace.config_path),
+        "created": not existing,
+        "placements": [ref.effective_id for ref in config_obj.placements],
+    }
+    if args.json:
+        print(json.dumps(result, indent=2))
+    else:
+        status = "Created" if not existing else "Updated"
+        print(f"{status} campaign '{campaign_id}' at {workspace.config_path}")
+        if config_obj.placements:
+            print("Placements:")
+            for ref in config_obj.placements:
+                print(f"  - {ref.effective_id}")
+    return 0
+
+
+def cmd_campaign_generate(args: argparse.Namespace) -> int:
+    try:
+        config, paths = _prepare_project(args)
+    except (InvalidPathError, RuntimeError) as exc:
+        return _fail(str(exc))
+
+    campaign_id = args.campaign_id.strip()
+    workspace = CampaignWorkspace(paths, campaign_id)
+    if not workspace.config_path.exists():
+        return _fail(f"Campaign '{campaign_id}' is not initialized. Run 'imgen campaign init {campaign_id}' first.")
+
+    try:
+        campaign_config = workspace.load_config()
+    except Exception as exc:  # noqa: BLE001
+        return _fail(f"Failed to read campaign config: {exc}")
+
+    workspace.ensure_scaffold()
+
+    routes = None
+    if args.routes:
+        routes = [item.strip() for item in args.routes.split(",") if item.strip()]
+    placements = None
+    if args.placements:
+        placements = [item.strip() for item in args.placements.split(",") if item.strip()]
+
+    variants_override = args.variants
+    provider_override = args.provider
+
+    try:
+        plans = plan_generation(
+            workspace,
+            campaign_config,
+            routes=routes,
+            placements=placements,
+            variants_override=variants_override,
+            provider_override=provider_override,
+        )
+    except DeterministicProviderError as exc:
+        return _fail(str(exc))
+    except Exception as exc:  # noqa: BLE001
+        return _fail(f"Failed to build generation plan: {exc}")
+
+    stats = execute_generation(
+        workspace,
+        plans,
+        generator_kind=args.generator,
+    )
+
+    result = {
+        "campaign_id": campaign_id,
+        "generated_variants": stats.generated,
+        "warnings": stats.warnings,
+    }
+    if args.json:
+        print(json.dumps(result, indent=2))
+    else:
+        print(f"Generated {stats.generated} variants for campaign '{campaign_id}'")
+        if stats.warnings:
+            print("Warnings:")
+            for warning in stats.warnings:
+                print(f"  - {warning}")
+    return 0
+
+
+def cmd_campaign_batch(args: argparse.Namespace) -> int:
+    try:
+        config, paths = _prepare_project(args)
+    except (InvalidPathError, RuntimeError) as exc:
+        return _fail(str(exc))
+
+    campaign_id = args.campaign_id.strip()
+    workspace = CampaignWorkspace(paths, campaign_id)
+    spec_path = Path(args.spec) if args.spec else workspace.batch_spec_path()
+    if not spec_path.exists():
+        return _fail(f"Batch spec not found at {spec_path}")
+
+    try:
+        spec = workspace.load_batch_spec(spec_path)
+    except Exception as exc:  # noqa: BLE001
+        return _fail(f"Failed to load batch spec: {exc}")
+
+    if spec.campaign_id != campaign_id:
+        return _fail(
+            f"Batch spec campaign_id '{spec.campaign_id}' does not match requested campaign '{campaign_id}'"
+        )
+
+    workspace.ensure_scaffold()
+
+    try:
+        plans = plan_from_batch_spec(workspace, spec)
+    except DeterministicProviderError as exc:
+        return _fail(str(exc))
+    except Exception as exc:  # noqa: BLE001
+        return _fail(f"Failed to build batch generation plan: {exc}")
+
+    stats = execute_generation(
+        workspace,
+        plans,
+        generator_kind=args.generator,
+    )
+
+    log_path = workspace.logs_dir / f"batch-{datetime.utcnow().strftime('%Y%m%d%H%M%S')}.jsonl"
+    log_path.parent.mkdir(parents=True, exist_ok=True)
+    with log_path.open("w", encoding="utf-8") as fh:
+        for event in stats.events:
+            fh.write(json.dumps(event))
+            fh.write("\n")
+
+    result = {
+        "campaign_id": campaign_id,
+        "generated_variants": stats.generated,
+        "log_path": str(log_path),
+        "warnings": stats.warnings,
+    }
+    if args.json:
+        print(json.dumps(result, indent=2))
+    else:
+        print(f"Batch run completed for '{campaign_id}' -> {stats.generated} variants")
+        print(f"Log: {log_path}")
+        if stats.warnings:
+            print("Warnings:")
+            for warning in stats.warnings:
+                print(f"  - {warning}")
+    return 0
+
+
+def cmd_campaign_review(args: argparse.Namespace) -> int:
+    try:
+        _, paths = _prepare_project(args, allow_create=False)
+    except (InvalidPathError, RuntimeError) as exc:
+        return _fail(str(exc))
+
+    campaign_id = args.campaign_id.strip()
+    workspace = CampaignWorkspace(paths, campaign_id)
+    manifest_path = workspace.placement_manifest_path(args.placement)
+    if not manifest_path.exists():
+        return _fail(f"Manifest not found for placement '{args.placement}'")
+
+    try:
+        manifest = workspace.load_manifest(args.placement)
+    except Exception as exc:  # noqa: BLE001
+        return _fail(f"Failed to load manifest: {exc}")
+
+    target_route = None
+    for route in manifest.routes:
+        if route.route_id == args.route:
+            target_route = route
+            break
+    if target_route is None:
+        return _fail(f"Route '{args.route}' not present in manifest")
+
+    target_variant = None
+    for variant in target_route.variants:
+        if variant.index == args.variant:
+            target_variant = variant
+            break
+    if target_variant is None:
+        return _fail(f"Variant index {args.variant} not found for route '{args.route}'")
+
+    state = ReviewState(args.state)
+    target_variant.review_state = state
+    if args.notes is not None:
+        target_variant.review_notes = args.notes
+
+    manifest.updated_at = datetime.utcnow().replace(microsecond=0).strftime("%Y-%m-%dT%H:%M:%SZ")
+    workspace.save_manifest(manifest)
+
+    result = {
+        "campaign_id": campaign_id,
+        "placement_id": args.placement,
+        "route_id": args.route,
+        "variant_index": args.variant,
+        "state": state.value,
+    }
+    if args.json:
+        print(json.dumps(result, indent=2))
+    else:
+        print(
+            f"Updated review state for {campaign_id} route={args.route} placement={args.placement} variant={args.variant} -> {state.value}"
+        )
+    return 0
+
+
+def cmd_campaign_export(args: argparse.Namespace) -> int:
+    try:
+        _, paths = _prepare_project(args, allow_create=False)
+    except (InvalidPathError, RuntimeError) as exc:
+        return _fail(str(exc))
+
+    campaign_id = args.campaign_id.strip()
+    workspace = CampaignWorkspace(paths, campaign_id)
+    include_states: List[ReviewState] = []
+    for state in (args.include or "").split(","):
+        if not state.strip():
+            continue
+        try:
+            include_states.append(ReviewState(state.strip()))
+        except ValueError:
+            return _fail(f"Invalid review state '{state}' in --include")
+    if not include_states:
+        include_states = [ReviewState.APPROVED]
+
+    export_id = f"{args.platform}-{datetime.utcnow().strftime('%Y%m%dT%H%M%SZ')}"
+    manifest_path = workspace.export_manifest_path(args.platform, export_id)
+    export_root = manifest_path.parent
+    export_root.mkdir(parents=True, exist_ok=True)
+
+    placements: set[str] = set()
+    routes_map: Dict[str, ExportRoute] = {}
+    export_files: List[ExportFile] = []
+    csv_records: List[tuple[str, str, str, str]] = []
+
+    for manifest in workspace.iter_manifests() or []:
+        placements.add(manifest.placement_id)
+        for route in manifest.routes:
+            routes_map.setdefault(route.route_id, ExportRoute(route_id=route.route_id, summary=route.summary))
+            for variant in route.variants:
+                if variant.review_state not in include_states:
+                    continue
+                source_path = workspace.root / variant.file
+                if not source_path.exists():
+                    continue
+                relative_path = Path(variant.file)
+                target_path = export_root / relative_path
+                target_path.parent.mkdir(parents=True, exist_ok=True)
+                copy2(source_path, target_path)
+                checksum = _sha256_of(target_path)
+                export_files.append(
+                    ExportFile(
+                        path=str(relative_path).replace("\\", "/"),
+                        placement_id=manifest.placement_id,
+                        variant_id=variant.variant_id,
+                        review_state=variant.review_state,
+                        checksum=checksum,
+                    )
+                )
+                csv_records.append(
+                    (
+                        variant.variant_id,
+                        manifest.placement_id,
+                        route.route_id,
+                        str(relative_path).replace("\\", "/"),
+                    )
+                )
+
+    csv_relative = Path(args.platform) / f"{args.platform}_upload.csv"
+    csv_path = export_root / csv_relative
+    csv_path.parent.mkdir(parents=True, exist_ok=True)
+    with csv_path.open("w", encoding="utf-8", newline="") as fh:
+        writer = csv.writer(fh)
+        writer.writerow(["variant_id", "placement_id", "route_id", "file"])
+        for record in csv_records:
+            writer.writerow(record)
+
+    csv_entry = ExportCsv(
+        name=f"{args.platform}_upload",
+        path=str(csv_relative).replace("\\", "/"),
+        profile=f"{args.platform}_v1",
+        checksum=_sha256_of(csv_path),
+        row_count=len(csv_records),
+    )
+
+    export_manifest = ExportManifest(
+        campaign_id=campaign_id,
+        platform=args.platform,
+        export_id=export_id,
+        generated_at=datetime.utcnow().replace(microsecond=0).strftime("%Y-%m-%dT%H:%M:%SZ"),
+        routes=list(routes_map.values()),
+        placements=sorted(placements),
+        include_states=include_states,
+        files=export_files,
+        csv_files=[csv_entry],
+    )
+
+    workspace.save_export_manifest(export_manifest, manifest_path)
+
+    output_zip = None
+    if args.output:
+        output_zip = Path(args.output)
+        output_zip.parent.mkdir(parents=True, exist_ok=True)
+        with zipfile.ZipFile(output_zip, "w", compression=zipfile.ZIP_DEFLATED) as archive:
+            for path in export_root.rglob("*"):
+                if path.is_dir():
+                    continue
+                archive.write(path, arcname=path.relative_to(export_root))
+
+    result = {
+        "campaign_id": campaign_id,
+        "platform": args.platform,
+        "export_id": export_id,
+        "export_dir": str(export_root),
+        "manifest": str(manifest_path),
+        "output_zip": str(output_zip) if output_zip else None,
+        "files": len(export_files),
+    }
+    if args.json:
+        print(json.dumps(result, indent=2))
+    else:
+        print(f"Export bundle created at {export_root}")
+        print(f"Manifest: {manifest_path}")
+        if output_zip:
+            print(f"Zip: {output_zip}")
+    return 0
+
+
 def _load_prompt_payload(prompt: Optional[str], prompt_file: Optional[str]) -> "PromptPayload":
     prompt_text = prompt
     request_text: Optional[str] = None
@@ -919,3 +1385,51 @@ def main(argv: Optional[list[str]] = None) -> int:
 
 if __name__ == "__main__":  # pragma: no cover
     raise SystemExit(main())
+def _load_structured_data(path: str | Path) -> Dict[str, Any]:
+    source: Path | None
+    if path == "-":
+        data = sys.stdin.read()
+        try:
+            return json.loads(data)
+        except json.JSONDecodeError:
+            import yaml
+
+            return yaml.safe_load(data) or {}
+    source = Path(path)
+    if not source.exists():
+        raise FileNotFoundError(f"File not found: {source}")
+    suffix = source.suffix.lower()
+    if suffix in {".json"}:
+        with source.open("r", encoding="utf-8") as fh:
+            return json.load(fh)
+    if suffix in {".yaml", ".yml"}:
+        import yaml
+
+        with source.open("r", encoding="utf-8") as fh:
+            return yaml.safe_load(fh) or {}
+    with source.open("r", encoding="utf-8") as fh:
+        text = fh.read()
+    try:
+        return json.loads(text)
+    except json.JSONDecodeError:
+        import yaml
+
+        return yaml.safe_load(text) or {}
+
+
+def _parse_metadata(pairs: Iterable[str]) -> Dict[str, str]:
+    result: Dict[str, str] = {}
+    for item in pairs:
+        if "=" not in item:
+            raise ValueError(f"Metadata '{item}' must be in key=value format")
+        key, value = item.split("=", 1)
+        result[key.strip()] = value.strip()
+    return result
+
+
+def _sha256_of(path: Path) -> str:
+    digest = hashlib.sha256()
+    with path.open("rb") as fh:
+        for chunk in iter(lambda: fh.read(65536), b""):
+            digest.update(chunk)
+    return digest.hexdigest()
